part of 'station_bloc.dart';

abstract class StationState extends Equatable {
  const StationState();

  @override
  List<Object> get props => [];
}

class StationInitial extends StationState {}

class StationLoadedState extends StationState {
  final List<Agency> agencies;
  final List<RbacStation> stations;
  const StationLoadedState({required this.stations, required this.agencies});
    @override
  List<Object> get props => [agencies,stations];
}

class StationLoadingState extends StationState {}

class StationErrorState extends StationState {
  final String message;
  const StationErrorState({required this.message});
    @override
  List<Object> get props => [message];
}

class FilterStationState extends StationState {
  final int agencyId;
  const FilterStationState({required this.agencyId});
}
